@@ -49,7 +49,6 @@
 #include "routines.h"
 #include "lexps.h"
 #include "sig2str.h"
-#include "long-options.h"
 #include "version-etc.h"
 
 /* From basename.c */
@@ -919,12 +918,6 @@ main (int argc, char *argv[])
 {
   int argn;
 
-  /* Architecture specific initialization. */
-#ifdef __EMX__
-  /* Wildcard expansion for OS/2 */
-  _wildcard (&argc, &argv);
-#endif
-
   /* Name under which this program was called. */
   program_name = base_name (argv[0]);
   /* program_invocation_name = xstrdup (program_name); */
@@ -938,12 +931,6 @@ main (int argc, char *argv[])
   bindtextdomain (PACKAGE "-gnulib", LOCALEDIR);
   textdomain (PACKAGE);
 
-  /* People don't want initializations when they just request a --help
-     or --version. */
-  parse_long_options (argc, argv,
-		      NULL, GNU_PACKAGE, VERSION,
-		      usage, "Akim Demaille", "Miguel Santana", (char const *) NULL);
-
   /* Catch the exits and signals to cleanup the mess.
 
      We do it now, though there is no tmp files before long, because I
@@ -1002,6 +989,20 @@ main (int argc, char *argv[])
 
   /* Process the command line options. */
   argn = a2ps_handle_options (job, argc, argv);
+  switch (behavior) {
+    case b_version:
+      version_etc (stdout, NULL, GNU_PACKAGE, VERSION,
+		   "Akim Demaille", "Miguel Santana", "Reuben Thomas", NULL);
+       return (EXIT_SUCCESS);
+      break;
+
+    case b_help:
+      usage (EXIT_SUCCESS);
+      break;
+
+    default: /* Ignore other options for now. */
+      break;
+  }
 
   /* Once a2ps.cfg is read, finish the building of a2ps_job */
   a2ps_job_finalize (job);
@@ -1062,15 +1063,6 @@ main (int argc, char *argv[])
 	pw_glob_print (job->common.path, argv[argn], stdout);
       break;
 
-    case b_version:
-      version_etc (stdout, NULL, GNU_PACKAGE, VERSION,
-		   "Akim Demaille", "Miguel Santana", NULL);
-      break;
-
-    case b_help:
-      usage (EXIT_SUCCESS);
-      break;
-
     case b_list_options:
       list_options (job, stdout);
       break;
@@ -1162,10 +1154,10 @@ main (int argc, char *argv[])
 	     * in is this one!
 	     * To this end, we need to put more information in file_job
 	     * on how its processing went. */
-	    
+
 	    struct file_job * file_job;
 	    size_t len;
-	    
+
 	    /* 'delegation_tmpname' is necessary not null else it is a
 	       failed job and we ignore it */
 	    file_job = CURRENT_FILE (job);
@@ -1175,7 +1167,7 @@ main (int argc, char *argv[])
 		len--;
 		file_job = job->jobs->content[len - 1];
 	      }
-	    
+
 	    a2ps_open_output_stream (job);
 	    pslex_dump (job->output_stream->fp, file_job->delegation_tmpname);
 	    unlink (file_job->delegation_tmpname);
