@@ -112,7 +112,6 @@
 
 #define YYDEBUG 1
 #define YYERROR_VERBOSE 1
-#define YYPRINT(file, type, value)   yyprint (file, type, value)
 
 /* We need to use the same `const' as bison, to avoid the following
    prototypes to diverge from the function declarations */
@@ -133,7 +132,6 @@ extern const char * sshfilename;
 
 /* Local prototypes */
 void yyerror (const char *msg);
-static void yyprint ();
 
 /* Initilizes the obstacks */
 void sshlex_initialize (void);
@@ -148,7 +146,7 @@ struct style_sheet * parse_style_sheet (const char * filename);
 static struct style_sheet * parsed_style_sheet = NULL;
 
 
-#line 152 "parsessh.c"
+#line 150 "parsessh.c"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -269,7 +267,7 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 82 "parsessh.y"
+#line 80 "parsessh.y"
 
   int integer;
   char * string;
@@ -285,7 +283,7 @@ union YYSTYPE
   struct fface_s fface;			/* Flagged face		*/
   enum case_sensitiveness sensitiveness;
 
-#line 289 "parsessh.c"
+#line 287 "parsessh.c"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -762,16 +760,16 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   130,   130,   137,   146,   149,   157,   163,   171,   177,
-     182,   186,   190,   196,   201,   206,   209,   212,   215,   218,
-     233,   234,   237,   239,   240,   253,   256,   257,   262,   269,
-     277,   284,   292,   296,   307,   315,   319,   323,   327,   331,
-     335,   342,   348,   359,   364,   371,   381,   386,   391,   397,
-     411,   416,   422,   434,   438,   445,   450,   455,   460,   472,
-     477,   484,   494,   498,   505,   511,   517,   522,   534,   539,
-     545,   555,   558,   564,   587,   595,   603,   611,   619,   627,
-     635,   643,   651,   659,   666,   674,   678,   686,   694,   700,
-     706,   715,   718
+       0,   128,   128,   135,   144,   147,   155,   161,   169,   175,
+     180,   184,   188,   194,   199,   204,   207,   210,   213,   216,
+     231,   232,   235,   237,   238,   251,   254,   255,   260,   267,
+     275,   282,   290,   294,   305,   313,   317,   321,   325,   329,
+     333,   340,   346,   357,   362,   369,   379,   384,   389,   395,
+     409,   414,   420,   432,   436,   443,   448,   453,   458,   470,
+     475,   482,   492,   496,   503,   509,   515,   520,   532,   537,
+     543,   553,   556,   562,   585,   593,   601,   609,   617,   625,
+     633,   641,   649,   657,   664,   672,   676,   684,   692,   698,
+     704,   713,   716
 };
 #endif
 
@@ -1460,33 +1458,33 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* file: style_sheet  */
-#line 131 "parsessh.y"
+#line 129 "parsessh.y"
     {
       parsed_style_sheet = (yyvsp[0].sheet);
     }
-#line 1468 "parsessh.c"
+#line 1466 "parsessh.c"
     break;
 
   case 3: /* style_sheet: tSTYLE tSTRING tIS definition_list tEND tSTYLE  */
-#line 138 "parsessh.y"
+#line 136 "parsessh.y"
       {
 	(yyvsp[-2].sheet)->name = (yyvsp[-4].string);
 	(yyvsp[-2].sheet)->key = "<No key yet>";
 	(yyval.sheet) = (yyvsp[-2].sheet);
       }
-#line 1478 "parsessh.c"
+#line 1476 "parsessh.c"
     break;
 
   case 4: /* definition_list: %empty  */
-#line 146 "parsessh.y"
+#line 144 "parsessh.y"
                     {
 	  (yyval.sheet) = new_style_sheet ((const unsigned char *) "<no name>");
 	}
-#line 1486 "parsessh.c"
+#line 1484 "parsessh.c"
     break;
 
   case 5: /* definition_list: definition_list tOPTIONAL tKEYWORDS keywords_def tKEYWORDS  */
-#line 150 "parsessh.y"
+#line 148 "parsessh.y"
         {
 	  if (highlight_level == 2) {
 	    words_set_no_face ((yyvsp[-1].words), Plain_fface);
@@ -1494,21 +1492,21 @@ yyreduce:
 	  }
 	  (yyval.sheet) = (yyvsp[-4].sheet);
 	}
-#line 1498 "parsessh.c"
+#line 1496 "parsessh.c"
     break;
 
   case 6: /* definition_list: definition_list tKEYWORDS keywords_def tKEYWORDS  */
-#line 158 "parsessh.y"
+#line 156 "parsessh.y"
         {
 	  words_set_no_face ((yyvsp[-1].words), Plain_fface);
 	  words_merge_rules_unique ((yyvsp[-3].sheet)->keywords, (yyvsp[-1].words));
 	  (yyval.sheet) = (yyvsp[-3].sheet);
 	}
-#line 1508 "parsessh.c"
+#line 1506 "parsessh.c"
     break;
 
   case 7: /* definition_list: definition_list tOPTIONAL tOPERATORS operators_def tOPERATORS  */
-#line 164 "parsessh.y"
+#line 162 "parsessh.y"
         {
 	  if (highlight_level == 2) {
 	    words_set_no_face ((yyvsp[-1].words), Plain_fface);
@@ -1516,112 +1514,112 @@ yyreduce:
 	  }
 	  (yyval.sheet) = (yyvsp[-4].sheet);
 	}
-#line 1520 "parsessh.c"
+#line 1518 "parsessh.c"
     break;
 
   case 8: /* definition_list: definition_list tOPERATORS operators_def tOPERATORS  */
-#line 172 "parsessh.y"
+#line 170 "parsessh.y"
         {
 	  words_set_no_face ((yyvsp[-1].words), Plain_fface);
 	  words_merge_rules_unique ((yyvsp[-3].sheet)->operators, (yyvsp[-1].words));
 	  (yyval.sheet) = (yyvsp[-3].sheet);
 	}
-#line 1530 "parsessh.c"
+#line 1528 "parsessh.c"
     break;
 
   case 9: /* definition_list: definition_list tOPTIONAL sequence_def  */
-#line 177 "parsessh.y"
+#line 175 "parsessh.y"
                                                  {
 	  if (highlight_level == 2)
 	    da_concat ((yyvsp[-2].sheet)->sequences, (yyvsp[0].array));
 	  (yyval.sheet) = (yyvsp[-2].sheet);
 	}
-#line 1540 "parsessh.c"
+#line 1538 "parsessh.c"
     break;
 
   case 10: /* definition_list: definition_list sequence_def  */
-#line 182 "parsessh.y"
+#line 180 "parsessh.y"
                                        {
 	  da_concat ((yyvsp[-1].sheet)->sequences, (yyvsp[0].array));
 	  (yyval.sheet) = (yyvsp[-1].sheet);
 	}
-#line 1549 "parsessh.c"
+#line 1547 "parsessh.c"
     break;
 
   case 11: /* definition_list: definition_list ancestors_def  */
-#line 186 "parsessh.y"
+#line 184 "parsessh.y"
                                         {
 	  da_concat ((yyvsp[-1].sheet)->ancestors, (yyvsp[0].array));
 	  (yyval.sheet) = (yyvsp[-1].sheet);
 	}
-#line 1558 "parsessh.c"
+#line 1556 "parsessh.c"
     break;
 
   case 12: /* definition_list: definition_list tALPHABETS tARE tSTRING  */
-#line 190 "parsessh.y"
+#line 188 "parsessh.y"
                                                   {
 	  string_to_array ((yyvsp[-3].sheet)->alpha1, (yyvsp[0].string));
 	  string_to_array ((yyvsp[-3].sheet)->alpha2, (yyvsp[0].string));
 	  (yyvsp[0].string) = NULL;
 	  (yyval.sheet) = (yyvsp[-3].sheet);
 	}
-#line 1569 "parsessh.c"
+#line 1567 "parsessh.c"
     break;
 
   case 13: /* definition_list: definition_list tFIRST tALPHABET tIS tSTRING  */
-#line 196 "parsessh.y"
+#line 194 "parsessh.y"
                                                        {
 	  string_to_array ((yyvsp[-4].sheet)->alpha1, (yyvsp[0].string));
 	  (yyvsp[0].string) = NULL;
 	  (yyval.sheet) = (yyvsp[-4].sheet);
 	}
-#line 1579 "parsessh.c"
+#line 1577 "parsessh.c"
     break;
 
   case 14: /* definition_list: definition_list tSECOND tALPHABET tIS tSTRING  */
-#line 201 "parsessh.y"
+#line 199 "parsessh.y"
                                                         {
 	  string_to_array ((yyvsp[-4].sheet)->alpha2, (yyvsp[0].string));
 	  (yyvsp[0].string) = NULL;
 	  (yyval.sheet) = (yyvsp[-4].sheet);
 	}
-#line 1589 "parsessh.c"
+#line 1587 "parsessh.c"
     break;
 
   case 15: /* definition_list: definition_list case_def  */
-#line 206 "parsessh.y"
+#line 204 "parsessh.y"
                                    {
 	  (yyvsp[-1].sheet)->sensitiveness = (yyvsp[0].sensitiveness);
 	}
-#line 1597 "parsessh.c"
+#line 1595 "parsessh.c"
     break;
 
   case 16: /* definition_list: definition_list documentation  */
-#line 209 "parsessh.y"
+#line 207 "parsessh.y"
                                         {
 	  (yyvsp[-1].sheet)->documentation = (yyvsp[0].string);
 	}
-#line 1605 "parsessh.c"
+#line 1603 "parsessh.c"
     break;
 
   case 17: /* definition_list: definition_list authors  */
-#line 212 "parsessh.y"
+#line 210 "parsessh.y"
                                   {
 	  (yyvsp[-1].sheet)->author = (yyvsp[0].string);
 	}
-#line 1613 "parsessh.c"
+#line 1611 "parsessh.c"
     break;
 
   case 18: /* definition_list: definition_list version  */
-#line 215 "parsessh.y"
+#line 213 "parsessh.y"
                                   {
 	  style_sheet_set_version ((yyvsp[-1].sheet), (const char *) (yyvsp[0].string));
 	}
-#line 1621 "parsessh.c"
+#line 1619 "parsessh.c"
     break;
 
   case 19: /* definition_list: definition_list requirement  */
-#line 218 "parsessh.y"
+#line 216 "parsessh.y"
                                       {
 	  /* Make sure now that we won't encounter new tokens.
 	   * This avoids nasty error messages, or worse:
@@ -1631,35 +1629,35 @@ yyreduce:
 		   _("cannot process `%s' which requires a2ps version %s"),
 		   sshfilename, (yyvsp[0].string));
 	}
-#line 1635 "parsessh.c"
+#line 1633 "parsessh.c"
     break;
 
   case 20: /* requirement: tREQUIRES tA2PS tSTRING  */
-#line 233 "parsessh.y"
+#line 231 "parsessh.y"
                                   { (yyval.string) = (yyvsp[0].string) ; }
-#line 1641 "parsessh.c"
+#line 1639 "parsessh.c"
     break;
 
   case 21: /* requirement: tREQUIRES tA2PS tVERSION tSTRING  */
-#line 234 "parsessh.y"
+#line 232 "parsessh.y"
                                            { (yyval.string) = (yyvsp[0].string) ; }
-#line 1647 "parsessh.c"
+#line 1645 "parsessh.c"
     break;
 
   case 22: /* documentation: tDOCUMENTATION tIS long_string tEND tDOCUMENTATION  */
-#line 237 "parsessh.y"
+#line 235 "parsessh.y"
                                                              { (yyval.string) = (yyvsp[-2].string) ; }
-#line 1653 "parsessh.c"
+#line 1651 "parsessh.c"
     break;
 
   case 23: /* long_string: tSTRING  */
-#line 239 "parsessh.y"
+#line 237 "parsessh.y"
                      { (yyval.string) = (yyvsp[0].string); }
-#line 1659 "parsessh.c"
+#line 1657 "parsessh.c"
     break;
 
   case 24: /* long_string: long_string tSTRING  */
-#line 241 "parsessh.y"
+#line 239 "parsessh.y"
         {
 	  size_t len1;
 	  size_t len2;
@@ -1670,38 +1668,38 @@ yyreduce:
 	  (yyval.string) = XNMALLOC (len1 + len2 + 2, unsigned char);
 	  stpcpy (stpncpy ((yyval.string), (yyvsp[-1].string), len1 + 1), (yyvsp[0].string));
 	}
-#line 1674 "parsessh.c"
+#line 1672 "parsessh.c"
     break;
 
   case 25: /* authors: tWRITTEN tBY tSTRING  */
-#line 253 "parsessh.y"
+#line 251 "parsessh.y"
                                 { (yyval.string) = (yyvsp[0].string) ; }
-#line 1680 "parsessh.c"
+#line 1678 "parsessh.c"
     break;
 
   case 26: /* version: tVERSION tIS tSTRING  */
-#line 256 "parsessh.y"
+#line 254 "parsessh.y"
                                 { (yyval.string) = (yyvsp[0].string) ; }
-#line 1686 "parsessh.c"
+#line 1684 "parsessh.c"
     break;
 
   case 27: /* version: tVERSION tSTRING  */
-#line 257 "parsessh.y"
+#line 255 "parsessh.y"
                                 { (yyval.string) = (yyvsp[0].string) ; }
-#line 1692 "parsessh.c"
+#line 1690 "parsessh.c"
     break;
 
   case 28: /* ancestors_def: tANCESTORS tARE ancestors_list tEND tANCESTORS  */
-#line 263 "parsessh.y"
+#line 261 "parsessh.y"
         {
 	  /* The list of keys of style sheets from which it inherits */
   	  (yyval.array) = (yyvsp[-2].array);
 	}
-#line 1701 "parsessh.c"
+#line 1699 "parsessh.c"
     break;
 
   case 29: /* ancestors_list: tSTRING  */
-#line 270 "parsessh.y"
+#line 268 "parsessh.y"
         {
 	  /* Create a list of ancestors, and drop the new one in */
 	  (yyval.array) = da_new ("Ancestors tmp", 2,
@@ -1709,34 +1707,34 @@ yyreduce:
 		       (da_print_func_t) da_str_print, NULL);
 	  da_append ((yyval.array), (yyvsp[0].string));
 	}
-#line 1713 "parsessh.c"
+#line 1711 "parsessh.c"
     break;
 
   case 30: /* ancestors_list: ancestors_list ',' tSTRING  */
-#line 278 "parsessh.y"
+#line 276 "parsessh.y"
         {
 	  da_append ((yyvsp[-2].array), (yyvsp[0].string));
 	  (yyval.array) = (yyvsp[-2].array);
 	}
-#line 1722 "parsessh.c"
+#line 1720 "parsessh.c"
     break;
 
   case 31: /* case_def: tCASE tSENSITIVENESS  */
-#line 284 "parsessh.y"
+#line 282 "parsessh.y"
                                 { (yyval.sensitiveness) = (yyvsp[0].sensitiveness) ; }
-#line 1728 "parsessh.c"
+#line 1726 "parsessh.c"
     break;
 
   case 32: /* regex: tREGEX  */
-#line 293 "parsessh.y"
+#line 291 "parsessh.y"
         {
 	  (yyval.pattern) = (yyvsp[0].pattern);
 	}
-#line 1736 "parsessh.c"
+#line 1734 "parsessh.c"
     break;
 
   case 33: /* regex: regex tREGEX  */
-#line 297 "parsessh.y"
+#line 295 "parsessh.y"
         {
 	  /* Concatenate $2 to $1 makes $$ */
 	  (yyval.pattern) = (yyvsp[-1].pattern);
@@ -1744,375 +1742,375 @@ yyreduce:
 	  strncpy ((yyval.pattern)->pattern + (yyval.pattern)->len, (yyvsp[0].pattern)->pattern, (yyvsp[0].pattern)->len);
 	  (yyval.pattern)->len += (yyvsp[0].pattern)->len;
 	}
-#line 1748 "parsessh.c"
+#line 1746 "parsessh.c"
     break;
 
   case 34: /* rhs: a_rhs  */
-#line 308 "parsessh.y"
+#line 306 "parsessh.y"
         {
 	  (yyval.array) = rhs_new ();
 	  rhs_add ((yyval.array), (yyvsp[0].faced_string));
 	}
-#line 1757 "parsessh.c"
+#line 1755 "parsessh.c"
     break;
 
   case 35: /* a_rhs: tSTRING fface  */
-#line 316 "parsessh.y"
+#line 314 "parsessh.y"
         {
 	  (yyval.faced_string) = faced_string_new  ((yyvsp[-1].string), 0, (yyvsp[0].fface));
 	}
-#line 1765 "parsessh.c"
+#line 1763 "parsessh.c"
     break;
 
   case 36: /* a_rhs: tSTRING  */
-#line 320 "parsessh.y"
+#line 318 "parsessh.y"
         {
 	  (yyval.faced_string) = faced_string_new  ((yyvsp[0].string), 0, No_fface);
 	}
-#line 1773 "parsessh.c"
+#line 1771 "parsessh.c"
     break;
 
   case 37: /* a_rhs: fface  */
-#line 324 "parsessh.y"
+#line 322 "parsessh.y"
         {
 	  (yyval.faced_string) = faced_string_new  (NULL, 0, (yyvsp[0].fface));
 	}
-#line 1781 "parsessh.c"
+#line 1779 "parsessh.c"
     break;
 
   case 38: /* a_rhs: tBACK_REF fface  */
-#line 328 "parsessh.y"
+#line 326 "parsessh.y"
         {
 	  (yyval.faced_string) = faced_string_new  (NULL, (yyvsp[-1].integer), (yyvsp[0].fface));
 	}
-#line 1789 "parsessh.c"
+#line 1787 "parsessh.c"
     break;
 
   case 39: /* a_rhs: tBACK_REF  */
-#line 332 "parsessh.y"
+#line 330 "parsessh.y"
         {
 	  (yyval.faced_string) = faced_string_new  (NULL, (yyvsp[0].integer), No_fface);
 	}
-#line 1797 "parsessh.c"
+#line 1795 "parsessh.c"
     break;
 
   case 40: /* a_rhs: tLATEXSYMBOL  */
-#line 336 "parsessh.y"
+#line 334 "parsessh.y"
         {
 	  (yyval.faced_string) = faced_string_new ((yyvsp[0].string), 0, Symbol_fface);
 	}
-#line 1805 "parsessh.c"
+#line 1803 "parsessh.c"
     break;
 
   case 41: /* rhs_list: a_rhs  */
-#line 343 "parsessh.y"
+#line 341 "parsessh.y"
         {
 	  (yyval.array) = rhs_new ();
 	  rhs_add ((yyval.array), (yyvsp[0].faced_string));
 	}
-#line 1814 "parsessh.c"
+#line 1812 "parsessh.c"
     break;
 
   case 42: /* rhs_list: rhs_list ',' a_rhs  */
-#line 349 "parsessh.y"
+#line 347 "parsessh.y"
         {
 	  rhs_add ((yyvsp[-2].array), (yyvsp[0].faced_string));
 	  (yyval.array) = (yyvsp[-2].array);
 	}
-#line 1823 "parsessh.c"
+#line 1821 "parsessh.c"
     break;
 
   case 43: /* fface: tFACE  */
-#line 360 "parsessh.y"
+#line 358 "parsessh.y"
         {
 	  fface_set_face ((yyval.fface), (yyvsp[0].face));
 	  fface_reset_flags ((yyval.fface));
 	}
-#line 1832 "parsessh.c"
+#line 1830 "parsessh.c"
     break;
 
   case 44: /* fface: tFFLAGS  */
-#line 365 "parsessh.y"
+#line 363 "parsessh.y"
         {
 	  fface_reset_face ((yyval.fface));
 	  fface_set_flags ((yyval.fface), (yyvsp[0].fflags));
 	  /* If there is no face, then set Invisible */
 	  fface_add_flags ((yyval.fface), ff_Invisible);
 	}
-#line 1843 "parsessh.c"
+#line 1841 "parsessh.c"
     break;
 
   case 45: /* fface: '(' fface_sxp ')'  */
-#line 372 "parsessh.y"
+#line 370 "parsessh.y"
         {
 	  (yyval.fface) = (yyvsp[-1].fface);
 	  /* If there is no face, then set Invisible */
 	  if (fface_get_face ((yyval.fface)) == No_face)
 	    fface_add_flags ((yyval.fface), ff_Invisible);
 	}
-#line 1854 "parsessh.c"
+#line 1852 "parsessh.c"
     break;
 
   case 46: /* fface_sxp: tFACE  */
-#line 382 "parsessh.y"
+#line 380 "parsessh.y"
         {
 	  fface_set_face((yyval.fface), (yyvsp[0].face));
 	  fface_reset_flags((yyval.fface));
 	}
-#line 1863 "parsessh.c"
+#line 1861 "parsessh.c"
     break;
 
   case 47: /* fface_sxp: tFFLAGS  */
-#line 387 "parsessh.y"
+#line 385 "parsessh.y"
         {
 	  fface_reset_face((yyval.fface));
 	  fface_set_flags((yyval.fface), (yyvsp[0].fflags));
 	}
-#line 1872 "parsessh.c"
+#line 1870 "parsessh.c"
     break;
 
   case 48: /* fface_sxp: fface_sxp '+' tFACE  */
-#line 392 "parsessh.y"
+#line 390 "parsessh.y"
         {
 	  /* FIXME: Overloading of the face should be forbidden */
 	  (yyval.fface) = (yyvsp[-2].fface);
 	  fface_set_face((yyval.fface), (yyvsp[0].face));
 	}
-#line 1882 "parsessh.c"
+#line 1880 "parsessh.c"
     break;
 
   case 49: /* fface_sxp: fface_sxp '+' tFFLAGS  */
-#line 398 "parsessh.y"
+#line 396 "parsessh.y"
         {
 	  (yyval.fface) = (yyvsp[-2].fface);
 	  fface_add_flags((yyval.fface), (yyvsp[0].fflags));
 	}
-#line 1891 "parsessh.c"
+#line 1889 "parsessh.c"
     break;
 
   case 50: /* rule: tSTRING rhs  */
-#line 412 "parsessh.y"
+#line 410 "parsessh.y"
         {
 	  (yyval.rule) = rule_new ((yyvsp[-1].string), NULL, (yyvsp[0].array),
 			 sshfilename, sshlineno);
 	}
-#line 1900 "parsessh.c"
+#line 1898 "parsessh.c"
     break;
 
   case 51: /* rule: tSTRING  */
-#line 417 "parsessh.y"
+#line 415 "parsessh.y"
         {
 	  (yyval.rule) = rule_new ((yyvsp[0].string), NULL,
 			 rhs_new_single (NULL, 0, No_fface),
 			 sshfilename, sshlineno);
 	}
-#line 1910 "parsessh.c"
+#line 1908 "parsessh.c"
     break;
 
   case 52: /* rule: '(' tSTRING rhs_list ')'  */
-#line 423 "parsessh.y"
+#line 421 "parsessh.y"
         {
 	  (yyval.rule) = rule_new ((yyvsp[-2].string), NULL, (yyvsp[-1].array),
 			 sshfilename, sshlineno);
 	}
-#line 1919 "parsessh.c"
+#line 1917 "parsessh.c"
     break;
 
   case 53: /* keywords_def: tIN fface tARE keywords_rule_list tEND  */
-#line 434 "parsessh.y"
+#line 432 "parsessh.y"
                                                       {
 	  words_set_no_face ((yyvsp[-1].words), (yyvsp[-3].fface));
 	  (yyval.words) = (yyvsp[-1].words);
 	}
-#line 1928 "parsessh.c"
+#line 1926 "parsessh.c"
     break;
 
   case 54: /* keywords_def: tARE keywords_rule_list tEND  */
-#line 438 "parsessh.y"
+#line 436 "parsessh.y"
                                        {
   	  /* First of all, the No_face must be turned into Plain */
   	  (yyval.words) = (yyvsp[-1].words);
 	}
-#line 1937 "parsessh.c"
+#line 1935 "parsessh.c"
     break;
 
   case 55: /* keywords_rule_list: rule  */
-#line 446 "parsessh.y"
+#line 444 "parsessh.y"
         {
 	  (yyval.words) = words_new ("Keywords: Strings", "Keywords: Regexps", 100, 100);
 	  words_add_string ((yyval.words), (yyvsp[0].rule));
 	}
-#line 1946 "parsessh.c"
+#line 1944 "parsessh.c"
     break;
 
   case 56: /* keywords_rule_list: keyword_regex  */
-#line 451 "parsessh.y"
+#line 449 "parsessh.y"
         {
 	  (yyval.words) = words_new ("Keywords: Strings", "Keywords: Regexps", 100, 100);
 	  words_add_regex ((yyval.words), (yyvsp[0].rule));
 	}
-#line 1955 "parsessh.c"
+#line 1953 "parsessh.c"
     break;
 
   case 57: /* keywords_rule_list: keywords_rule_list ',' rule  */
-#line 456 "parsessh.y"
+#line 454 "parsessh.y"
         {
 	  words_add_string ((yyvsp[-2].words), (yyvsp[0].rule));
 	  (yyval.words) = (yyvsp[-2].words);
 	}
-#line 1964 "parsessh.c"
+#line 1962 "parsessh.c"
     break;
 
   case 58: /* keywords_rule_list: keywords_rule_list ',' keyword_regex  */
-#line 461 "parsessh.y"
+#line 459 "parsessh.y"
         {
 	  words_add_regex ((yyvsp[-2].words), (yyvsp[0].rule));
 	  (yyval.words) = (yyvsp[-2].words);
 	}
-#line 1973 "parsessh.c"
+#line 1971 "parsessh.c"
     break;
 
   case 59: /* keyword_regex: regex rhs  */
-#line 473 "parsessh.y"
+#line 471 "parsessh.y"
         {
 	  (yyval.rule) = keyword_rule_new (NULL, (yyvsp[-1].pattern), (yyvsp[0].array),
 				 sshfilename, sshlineno);
 	}
-#line 1982 "parsessh.c"
+#line 1980 "parsessh.c"
     break;
 
   case 60: /* keyword_regex: regex  */
-#line 478 "parsessh.y"
+#line 476 "parsessh.y"
         {
 	  (yyval.rule) = keyword_rule_new (NULL, (yyvsp[0].pattern),
 				   rhs_new_single (NULL, 0,
 							    No_fface),
 				 sshfilename, sshlineno);
 	}
-#line 1993 "parsessh.c"
+#line 1991 "parsessh.c"
     break;
 
   case 61: /* keyword_regex: '(' regex rhs_list ')'  */
-#line 485 "parsessh.y"
+#line 483 "parsessh.y"
         {
 	  (yyval.rule) = keyword_rule_new (NULL, (yyvsp[-2].pattern), (yyvsp[-1].array),
 				 sshfilename, sshlineno);
 	}
-#line 2002 "parsessh.c"
+#line 2000 "parsessh.c"
     break;
 
   case 62: /* operators_def: tIN fface tARE operators_rule_list tEND  */
-#line 494 "parsessh.y"
+#line 492 "parsessh.y"
                                                        {
 	  words_set_no_face ((yyvsp[-1].words), (yyvsp[-3].fface));
 	  (yyval.words) = (yyvsp[-1].words);
 	}
-#line 2011 "parsessh.c"
+#line 2009 "parsessh.c"
     break;
 
   case 63: /* operators_def: tARE operators_rule_list tEND  */
-#line 498 "parsessh.y"
+#line 496 "parsessh.y"
                                         {
   	  /* First of all, the No_face must be turned into Plain */
   	  (yyval.words) = (yyvsp[-1].words);
 	}
-#line 2020 "parsessh.c"
+#line 2018 "parsessh.c"
     break;
 
   case 64: /* operators_rule_list: rule  */
-#line 506 "parsessh.y"
+#line 504 "parsessh.y"
         {
 	  (yyval.words) = words_new ("Operators: Strings", "Operators: Regexps",
 			  100, 100);
 	  words_add_string ((yyval.words), (yyvsp[0].rule));
 	}
-#line 2030 "parsessh.c"
+#line 2028 "parsessh.c"
     break;
 
   case 65: /* operators_rule_list: operator_regex  */
-#line 512 "parsessh.y"
+#line 510 "parsessh.y"
         {
 	  (yyval.words) = words_new ("Operators: Strings", "Operators: Regexps",
 			  100, 100);
 	  words_add_regex ((yyval.words), (yyvsp[0].rule));
 	}
-#line 2040 "parsessh.c"
+#line 2038 "parsessh.c"
     break;
 
   case 66: /* operators_rule_list: operators_rule_list ',' rule  */
-#line 518 "parsessh.y"
+#line 516 "parsessh.y"
         {
 	  words_add_string ((yyvsp[-2].words), (yyvsp[0].rule));
 	  (yyval.words) = (yyvsp[-2].words);
 	}
-#line 2049 "parsessh.c"
+#line 2047 "parsessh.c"
     break;
 
   case 67: /* operators_rule_list: operators_rule_list ',' operator_regex  */
-#line 523 "parsessh.y"
+#line 521 "parsessh.y"
         {
 	  words_add_regex ((yyvsp[-2].words), (yyvsp[0].rule));
 	  (yyval.words) = (yyvsp[-2].words);
 	}
-#line 2058 "parsessh.c"
+#line 2056 "parsessh.c"
     break;
 
   case 68: /* operator_regex: regex rhs  */
-#line 535 "parsessh.y"
+#line 533 "parsessh.y"
         {
 	  (yyval.rule) = rule_new (NULL, (yyvsp[-1].pattern), (yyvsp[0].array),
 			 sshfilename, sshlineno);
 	}
-#line 2067 "parsessh.c"
+#line 2065 "parsessh.c"
     break;
 
   case 69: /* operator_regex: regex  */
-#line 540 "parsessh.y"
+#line 538 "parsessh.y"
         {
 	  (yyval.rule) = rule_new (NULL, (yyvsp[0].pattern),
 			   rhs_new_single (NULL, 0, No_fface),
 			 sshfilename, sshlineno);
 	}
-#line 2077 "parsessh.c"
+#line 2075 "parsessh.c"
     break;
 
   case 70: /* operator_regex: '(' regex rhs_list ')'  */
-#line 546 "parsessh.y"
+#line 544 "parsessh.y"
         {
 	  (yyval.rule) = rule_new (NULL, (yyvsp[-2].pattern), (yyvsp[-1].array),
 			 sshfilename, sshlineno);
 	}
-#line 2086 "parsessh.c"
+#line 2084 "parsessh.c"
     break;
 
   case 71: /* sequence_def: tSEQUENCES tARE sequence_list tEND tSEQUENCES  */
-#line 555 "parsessh.y"
+#line 553 "parsessh.y"
                                                              { (yyval.array) = (yyvsp[-2].array); }
-#line 2092 "parsessh.c"
+#line 2090 "parsessh.c"
     break;
 
   case 72: /* sequence_list: sequence  */
-#line 558 "parsessh.y"
+#line 556 "parsessh.y"
                         {
 	  (yyval.array) = da_new ("Sequence tmp", 100,
 		       da_linear, 100,
 		       (da_print_func_t) sequence_self_print, NULL);
 	  da_append ((yyval.array), (yyvsp[0].sequence));
 	}
-#line 2103 "parsessh.c"
+#line 2101 "parsessh.c"
     break;
 
   case 73: /* sequence_list: sequence_list ',' sequence  */
-#line 564 "parsessh.y"
+#line 562 "parsessh.y"
                                      {
 	  da_append ((yyvsp[-2].array), (yyvsp[0].sequence));
 	  (yyval.array) = (yyvsp[-2].array);
 	}
-#line 2112 "parsessh.c"
+#line 2110 "parsessh.c"
     break;
 
   case 74: /* sequence: tSTRING tLATEXSYMBOL fface closers_opt exception_def_opt  */
-#line 588 "parsessh.y"
+#line 586 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new ((yyvsp[-4].string), NULL,
@@ -2120,11 +2118,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2124 "parsessh.c"
+#line 2122 "parsessh.c"
     break;
 
   case 75: /* sequence: tSTRING tSTRING fface fface closers_opt exception_def_opt  */
-#line 596 "parsessh.y"
+#line 594 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new ((yyvsp[-5].string), NULL,
@@ -2132,11 +2130,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2136 "parsessh.c"
+#line 2134 "parsessh.c"
     break;
 
   case 76: /* sequence: tSTRING fface fface closers_opt exception_def_opt  */
-#line 604 "parsessh.y"
+#line 602 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new ((yyvsp[-4].string), NULL,
@@ -2144,11 +2142,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2148 "parsessh.c"
+#line 2146 "parsessh.c"
     break;
 
   case 77: /* sequence: tSTRING tSTRING fface closers_opt exception_def_opt  */
-#line 612 "parsessh.y"
+#line 610 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new ((yyvsp[-4].string), NULL,
@@ -2156,11 +2154,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2160 "parsessh.c"
+#line 2158 "parsessh.c"
     break;
 
   case 78: /* sequence: tSTRING fface closers_opt exception_def_opt  */
-#line 620 "parsessh.y"
+#line 618 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new ((yyvsp[-3].string), NULL,
@@ -2168,11 +2166,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2172 "parsessh.c"
+#line 2170 "parsessh.c"
     break;
 
   case 79: /* sequence: regex tSTRING fface fface closers_opt exception_def_opt  */
-#line 628 "parsessh.y"
+#line 626 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new (NULL, (yyvsp[-5].pattern),
@@ -2180,11 +2178,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2184 "parsessh.c"
+#line 2182 "parsessh.c"
     break;
 
   case 80: /* sequence: regex fface fface closers_opt exception_def_opt  */
-#line 636 "parsessh.y"
+#line 634 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new (NULL, (yyvsp[-4].pattern),
@@ -2192,11 +2190,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2196 "parsessh.c"
+#line 2194 "parsessh.c"
     break;
 
   case 81: /* sequence: regex tSTRING fface closers_opt exception_def_opt  */
-#line 644 "parsessh.y"
+#line 642 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new (NULL, (yyvsp[-4].pattern),
@@ -2204,11 +2202,11 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2208 "parsessh.c"
+#line 2206 "parsessh.c"
     break;
 
   case 82: /* sequence: regex fface closers_opt exception_def_opt  */
-#line 652 "parsessh.y"
+#line 650 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new (NULL, (yyvsp[-3].pattern),
@@ -2216,49 +2214,49 @@ yyreduce:
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2220 "parsessh.c"
+#line 2218 "parsessh.c"
     break;
 
   case 83: /* sequence: '(' tSTRING rhs_list ')' fface closers_opt exception_def_opt  */
-#line 660 "parsessh.y"
+#line 658 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new ((yyvsp[-5].string), NULL, (yyvsp[-4].array),
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2231 "parsessh.c"
+#line 2229 "parsessh.c"
     break;
 
   case 84: /* sequence: '(' regex rhs_list ')' fface closers_opt exception_def_opt  */
-#line 667 "parsessh.y"
+#line 665 "parsessh.y"
         {
 	  struct rule * open_rule;
 	  open_rule = rule_new (NULL, (yyvsp[-5].pattern), (yyvsp[-4].array),
 				sshfilename, sshlineno);
 	  (yyval.sequence) = sequence_new (open_rule, (yyvsp[-2].fface), (yyvsp[-1].words), (yyvsp[0].words));
 	}
-#line 2242 "parsessh.c"
+#line 2240 "parsessh.c"
     break;
 
   case 85: /* sequence: tCSTRING  */
-#line 675 "parsessh.y"
+#line 673 "parsessh.y"
         {
 	  (yyval.sequence) = new_C_string_sequence ("\"");
 	}
-#line 2250 "parsessh.c"
+#line 2248 "parsessh.c"
     break;
 
   case 86: /* sequence: tCCHAR  */
-#line 679 "parsessh.y"
+#line 677 "parsessh.y"
         {
 	  (yyval.sequence) = new_C_string_sequence ("\'");
 	}
-#line 2258 "parsessh.c"
+#line 2256 "parsessh.c"
     break;
 
   case 87: /* closers_opt: %empty  */
-#line 686 "parsessh.y"
+#line 684 "parsessh.y"
         {
 	  /* This is a shortcut which means "up to the end of the line". */
 	  (yyval.words) = words_new ("Closing: Strings", "Closing: Regexps", 2, 2);
@@ -2267,56 +2265,56 @@ yyreduce:
 							  No_fface),
 					  sshfilename, sshlineno));
 	}
-#line 2271 "parsessh.c"
+#line 2269 "parsessh.c"
     break;
 
   case 88: /* closers_opt: rule  */
-#line 695 "parsessh.y"
+#line 693 "parsessh.y"
         {
 	  /* Only one */
 	  (yyval.words) = words_new ("Closing: Strings", "Closing: Regexps", 2, 2);
 	  words_add_string ((yyval.words), (yyvsp[0].rule));
 	}
-#line 2281 "parsessh.c"
+#line 2279 "parsessh.c"
     break;
 
   case 89: /* closers_opt: operator_regex  */
-#line 701 "parsessh.y"
+#line 699 "parsessh.y"
         {
 	  /* Only one */
 	  (yyval.words) = words_new ("Closing: Strings", "Closing: Regexps", 2, 2);
 	  words_add_regex ((yyval.words), (yyvsp[0].rule));
 	}
-#line 2291 "parsessh.c"
+#line 2289 "parsessh.c"
     break;
 
   case 90: /* closers_opt: tCLOSERS operators_def tCLOSERS  */
-#line 707 "parsessh.y"
+#line 705 "parsessh.y"
         {
 	  /* Several, comma separated, between () */
 	  (yyval.words) = (yyvsp[-1].words);
 	}
-#line 2300 "parsessh.c"
+#line 2298 "parsessh.c"
     break;
 
   case 91: /* exception_def_opt: %empty  */
-#line 715 "parsessh.y"
+#line 713 "parsessh.y"
         {
 	  (yyval.words) = words_new ("Exceptions: Strings", "Exceptions: Regexps", 1, 1);
 	}
-#line 2308 "parsessh.c"
+#line 2306 "parsessh.c"
     break;
 
   case 92: /* exception_def_opt: tEXCEPTIONS operators_def tEXCEPTIONS  */
-#line 719 "parsessh.y"
+#line 717 "parsessh.y"
         {
 	  (yyval.words) = (yyvsp[-1].words);
 	}
-#line 2316 "parsessh.c"
+#line 2314 "parsessh.c"
     break;
 
 
-#line 2320 "parsessh.c"
+#line 2318 "parsessh.c"
 
       default: break;
     }
@@ -2509,7 +2507,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 723 "parsessh.y"
+#line 721 "parsessh.y"
 
 
 void
@@ -2518,36 +2516,6 @@ yyerror (const char *msg)
   error_at_line (1, 0, sshfilename, sshlineno, "%s", msg);
 }
 
-/*
- * FIXME: Cover the other relevant types
- */
-static void
-yyprint (FILE *file, int type, YYSTYPE value)
-{
-  switch (type) {
-  case tBACK_REF:
-    fprintf (file, " \\%d", value.integer);
-    break;
-
-  case tFFLAGS:
-    putc (' ', file);
-    fflag_self_print (value.fflags, file);
-    break;
-
-  case tFACE:
-    fprintf (file, " %s", face_to_string (value.face));
-    break;
-
-  case tREGEX:
-    fprintf (file, " /%s/", value.pattern->pattern);
-    break;
-
-  case tSTRING:
-    fprintf (file, " \"%s\"", value.string);
-    break;
-  }
-}
-
 struct style_sheet *
 parse_style_sheet (const char * filename)
 {
