@@ -1,33 +1,26 @@
-/*
- * read.c --- routines of input with no style sheets
- *
- * Copyright (c) 1988-1993 Miguel Santana
- * Copyright (c) 1995-2000 Akim Demaille, Miguel Santana
- *
- */
+/* read.c - routines of input with no style sheets
+   Copyright 1988-2017 Free Software Foundation, Inc.
 
-/*
- * This file is part of a2ps.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+   02110-1301, USA.  */
+
+#include <config.h>
 
 #include "main.h"
 #include "buffer.h"
-
+
 
 /*-------------------------------------------------------.
 | Returns a single char (EOF for end-of-file).           |
@@ -38,7 +31,7 @@
 static int
 plain_getc (buffer_t * buffer, enum face_e *face)
 {
-  uchar c;
+  char c;
 
   if (buffer_is_empty (buffer))
     {
@@ -55,17 +48,17 @@ plain_getc (buffer_t * buffer, enum face_e *face)
     }
 
   *face = Plain;
-  c = buffer->content[(buffer->curr)++];
+  c = (char) buffer->content[(buffer->curr)++];
 
   /* Check if it is a special nroff'ed sequence */
   if (buffer->content[buffer->curr] == '\b')
     {
-      /* We might be dealing with misceleanous nroff'ed pages. */
-      const uchar *input = buffer->content + buffer->curr + 1;
+      /* We might be dealing with miscellaneous nroff'ed pages. */
+      const char *input = (char *) buffer->content + buffer->curr + 1;
 
       /* This might be a bolding sequence.  The bad news is that some
 	 strange systems build the bold sequences with only one
-	 rewriting, not the 3 usuals.
+	 rewriting, not the usual 3.
 
 	 Super strong `_', seen in Sun's mpeg_rc doc.  */
       if (c	== input[0] &&
@@ -134,7 +127,7 @@ plain_getc (buffer_t * buffer, enum face_e *face)
 	{
 	  *face = Symbol;
 	  buffer->curr += 2;
-	  c = 0305; /* \oplus in LaTeX */
+	  c = '\305'; /* \oplus in LaTeX */
 	}
       /* Seen in groff.1 : c;\b;O, for copyright */
       else if ('c' == c &&
@@ -142,7 +135,7 @@ plain_getc (buffer_t * buffer, enum face_e *face)
 	{
 	  *face = Symbol;
 	  buffer->curr += 2;
-	  c = 0343; /* \copyright. */
+	  c = '\343'; /* \copyright. */
 	}
       /* Seen in gtroff.1 : +;\b;_, for plus or minus */
       else if ('+' == c &&
@@ -150,7 +143,7 @@ plain_getc (buffer_t * buffer, enum face_e *face)
 	{
 	  *face = Symbol;
 	  buffer->curr += 2;
-	  c = 0261;
+	  c = '\261';
 	}
       /* Seen in geqn.1 : ~;\b>;\b;_ for greater or equal */
       else if ('~'  == c &&
@@ -160,7 +153,7 @@ plain_getc (buffer_t * buffer, enum face_e *face)
 	{
 	  *face = Symbol;
 	  buffer->curr += 4;
-	  c = 0263;
+	  c = '\263';
 	}
       /* Less than or equal to. */
       else if ('~'  == c &&
@@ -170,7 +163,7 @@ plain_getc (buffer_t * buffer, enum face_e *face)
 	{
 	  *face = Symbol;
 	  buffer->curr += 4;
-	  c = 0243;
+	  c = '\243';
 	}
       /* Underlined: x;\b;_ . Note that we have a conflict here in the
 	 case x == '+' (see above).  This choice seems the best.  */
@@ -189,9 +182,9 @@ plain_getc (buffer_t * buffer, enum face_e *face)
 	}
       /* else: treate the backslash as a special characters */
     }
-  return c;
+  return (unsigned char)c;
 }
-
+
 /*
  * Print a file to postscript (no style)
  */
@@ -202,5 +195,5 @@ plain_print_postscript (a2ps_job * Job, buffer_t * buffer)
   int c;
 
   while ((c = plain_getc (buffer, &face)) != EOF)
-    ps_print_char (Job, c, face);
+    ps_print_char (Job, (char) c, face);
 }
